@@ -1,4 +1,4 @@
-from player_metric.metric import agg_metric_helper, per_game_metric_helper
+from .metric import agg_metric_helper, per_game_metric_helper
 
 class PlayerMetric:
     """
